@@ -125,12 +125,12 @@ class SearchFilter(BaseSearchFilter):
 
     def get_search_terms(self, request):
         """
-        Search terms are set by a ?search=... query parameter,
-        and may be comma and/or whitespace delimited.
+        Search terms are set by a ?q=... query parameter.
+        When multiple search terms must be matched, they can be delimited
+        by a comma.
         """
         params = request.query_params.get(self.search_param, '')
         params = params.replace('\x00', '')  # strip null characters
-        params = params.replace(',', ' ')
         results = []
         inside = False
         first = 0
@@ -142,7 +142,7 @@ class SearchFilter(BaseSearchFilter):
                     first = last + 1
                     inside = False
             else:
-                if letter in (' ', '\t'):
+                if letter in (',',):
                     if first < last:
                         results += [params[first:last]]
                     first = last + 1
