@@ -1,4 +1,4 @@
-# Copyright (c) 2020, DjaoDjin inc.
+# Copyright (c) 2022, DjaoDjin inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -26,7 +26,6 @@ from __future__ import unicode_literals
 from django import forms
 from django.contrib import messages
 from django.http import HttpResponseRedirect
-from django.utils.translation import ugettext_lazy as _
 from django.views.generic import (CreateView, ListView, UpdateView,
     TemplateView)
 from django.views.generic.detail import SingleObjectMixin
@@ -34,7 +33,8 @@ from django.template.context_processors import csrf
 
 from . import RedirectFormMixin
 from .. import settings
-from ..compat import is_authenticated, reverse, reverse_lazy
+from ..compat import (gettext_lazy as _, is_authenticated, reverse,
+    reverse_lazy)
 from ..forms import PlanForm
 from ..mixins import CartMixin, OrganizationMixin, ProviderMixin
 from ..models import CartItem, Coupon, Plan
@@ -45,6 +45,7 @@ class PlanFormMixin(OrganizationMixin, SingleObjectMixin):
 
     model = Plan
     form_class = PlanForm
+    plan_url_kwarg = 'plan'
 
     def get_initial(self):
         """
@@ -75,9 +76,9 @@ class PlanFormMixin(OrganizationMixin, SingleObjectMixin):
         if hasattr(self, 'object') and self.object:
             plan_kwarg = self.object.slug
         else:
-            plan_kwarg = kwargs.get('plan')
+            plan_kwarg = kwargs.get(self.plan_url_kwarg)
         if plan_kwarg:
-            url_kwargs.update({'plan': plan_kwarg})
+            url_kwargs.update({self.plan_url_kwarg: plan_kwarg})
         return url_kwargs
 
 
